@@ -1,4 +1,3 @@
-from __future__ import generators
 """
 This is a matlab(TM) style functional interface the matplotlib.
 
@@ -16,6 +15,7 @@ Plotting commands
   axis     - Set or return the current axis limits
   bar      - make a bar chart
   barh     - a horizontal bar chart  
+  boxplot  - make a box and whisker plot
   cla      - clear current axes
   clf      - clear a figure window
   close    - close a figure window
@@ -140,11 +140,13 @@ John D. Hunter <jdhunter@ace.bsd.uhicago.edu>
 Most of the other commands are from the Numeric, MLab and FFT, with
 the exception of those in mlab.py provided by matplotlib.
 """
-__version__  = '0.71'
-__revision__ = '$Revision: 1.30 $'
-__date__     = '$Date: 2005/01/21 19:52:47 $'
+from __future__ import generators
 
-import sys, os
+__version__  = '0.82'
+__revision__ = '$Revision: 1.65 $'
+__date__     = '$Date: 2005/06/15 18:27:37 $'
+
+import sys, os, warnings
 import distutils.sysconfig
 
 if not hasattr(sys, 'argv'):  # for modpython
@@ -189,11 +191,11 @@ class Verbose:
     A class to handle reporting.  Set the fileo attribute to any file
     instance to handle the output.  Default is sys.stdout
     """
-    levels = ('silent', 'error', 'helpful', 'debug', 'debug-annoying')
+    levels = ('silent', 'helpful', 'debug', 'debug-annoying')
     vald = dict( [(level, i) for i,level in enumerate(levels)])
 
     # parse the verbosity from the command line; flags look like
-    # --verbose-error or --verbose-helpful
+    # --verbose-silent or --verbose-helpful
     _commandLineVerbose = None
 
 
@@ -206,7 +208,6 @@ class Verbose:
     def __init__(self, level):
         self.set_level(level)
         self.fileo = sys.stdout
-        self.erro = sys.stderr
         
     def set_level(self, level):
         'set the verbosity to one of the Verbose.levels strings'
@@ -228,16 +229,6 @@ class Verbose:
             return True
         return False
 
-    def report_error(self, s):
-        """
-        print message s to self.fileo if self.level>=level.  Return
-        value indicates whether a message was issued
-        
-        """
-        if self.ge('error'):
-            print >>self.erro, s
-            return True
-        return False
 
 
     def wrap(self, fmt, func, level='helpful', always=True):
@@ -266,7 +257,7 @@ class Verbose:
         return self.vald[self.level]>=self.vald[level]
 
         
-verbose=Verbose('error')  
+verbose=Verbose('silent')  
 
 def get_home():
     """
@@ -297,6 +288,12 @@ def _get_data_path():
     path = os.path.join(distutils.sysconfig.PREFIX, 'share', 'py-matplotlib')
     if os.path.isdir(path): return path
 
+    path = '/usr/local/share/py-matplotlib'
+    if os.path.isdir(path): return path
+
+    path = '/usr/share/py-matplotlib'
+    if os.path.isdir(path): return path
+
     path = os.path.join(os.sep.join(__file__.split(os.sep)[:-1]), 
                         'share','py-matplotlib')
     if os.path.isdir(path): return path
@@ -305,14 +302,19 @@ def _get_data_path():
                         'share','py-matplotlib')
     if os.path.isdir(path): return path
 
-	
     # CODE ADDED TO SUPPORT PY2EXE - you will need to copy
     # C:\Python23\share\matplotlib into your dist dir.  See
     # http://starship.python.net/crew/theller/moin.cgi/MatPlotLib
     # for more info
-    if sys.platform=='win32' and sys.frozen:
-        path = os.path.join(os.path.split(sys.path[0])[0], 'matplotlibdata')
-        return path
+
+    if sys.platform=='win32' and sys.frozen: 
+        path = os.path.join(os.path.split(sys.path[0])[0], 'matplotlibdata') 
+        if os.path.isdir(path):  return path 
+        else:
+            # Try again assuming sys.path[0] is a dir not a exe 
+            path = os.path.join(sys.path[0], 'matplotlibdata') 
+            if os.path.isdir(path): return path
+
     raise RuntimeError('Could not find the matplotlib data files')
 
 get_data_path = verbose.wrap('matplotlib data path %s', _get_data_path, always=False)
@@ -394,11 +396,16 @@ def validate_color(s):
         try: return float(s)
         except ValueError:
             raise ValueError('Could not convert "%s" to float' % s)
-        
-    if len(s)==6 and s.isalnum: # looks like hex
+
+    
+    if len(s)==6 and s.isalnum(): # looks like hex
         return '#' + s
 
-    raise ValueError('"s" does not look like color arg')
+    if s.isalpha(): 
+        #assuming a color name, hold on
+        return s
+
+    raise ValueError('"s" does not look like color arg')    
 
 def validate_comma_sep_str(s):
     'return a list'
@@ -408,11 +415,22 @@ def validate_comma_sep_str(s):
     except ValueError:
         raise ValueError('Could not convert all entries to strings')
 
-def validate_orientation(s):
-    if s.lower() in ['landscape', 'portrait']:
-        return True
-    else:
-        raise ValueError('orientation must be one of: portrait, landscape')
+class ValidateInStrings:
+    def __init__(self, valid, ignorecase=False):
+        'valid is a list of legal strings'
+        self.ignorecase = ignorecase
+        def func(s):
+            if ignorecase: return s.lower()
+            else: return s
+        self.validd = dict([(func(k),1) for k in valid])
+
+    def __call__(self, s):
+        if self.ignorecase: s = s.lower()
+        if s in self.validd: return s
+        raise ValueError('Unrecognized string "%s": valid strings are %s'%(s, self.validd.keys()))
+
+
+validate_orientation = ValidateInStrings(['landscape', 'portrait'])
 
 def validate_fontsize(s):
     if s.lower() in ['xx-small', 'x-small', 'small', 'medium', 'large', 'x-large',
@@ -443,21 +461,49 @@ def validate_verbose_fileo(s):
         else:
             verbose.fileo = fileo
     return verbose.fileo
+    
 
-def validate_verbose_erro(s):
-    d = {'sys.stdout':sys.stdout,
-         'sys.stderr':sys.stderr,
-         }
-    if d.has_key(s): verbose.erro = d[s]
-    else:
-        try: erro = file(s, 'w')
-        except IOError:
-            raise ValueError('Verbose object could not open log file "%s" for writing.\nCheck your matplotlibrc verbose.erro setting'%s)
+validate_ps_papersize = ValidateInStrings([
+        'executive', 'letter', 'legal', 'ledger',
+        'a0', 'a1', 'a2','a3', 'a4', 'a5', 'a6', 'a7', 'a8', 'a9', 'a10',
+        'b0', 'b1', 'b2', 'b3', 'b4', 'b5', 'b6',
+        'c0', 'c1', 'c2', 'c3', 'c4', 'c5', 'c6'
+        ], ignorecase=True)
+
+validate_tex_engine = ValidateInStrings(['tex', 'latex'], ignorecase=True)
+
+validate_joinstyle = ValidateInStrings(['miter', 'round', 'bevel'], ignorecase=True)
+
+validate_capstyle = ValidateInStrings(['butt', 'round', 'projecting'], ignorecase=True)
+
+
+class ValidateInterval:
+    """
+    Value must be in interval 
+    """
+    def __init__(self, vmin, vmax, closedmin=True, closedmax=True):
+        self.vmin = vmin
+        self.vmax = vmax
+        self.cmin = closedmin
+        self.cmax = closedmax
+
+    def __call__(self, s):
+        try: s = float(s)
+        except: raise RuntimeError('Value must be a float; found "%s"'%s)
+
+        if self.cmin and s<self.vmin:
+            raise RuntimeError('Value must be >= %f; found "%f"'%(self.vmin, s))
+        elif not self.cmin and s<=self.vmin:
+            raise RuntimeError('Value must be > %f; found "%f"'%(self.vmin, s))
+
+        if self.cmax and s>self.vmax:
+            raise RuntimeError('Value must be <= %f; found "%f"'%(self.vmax, s))
+        elif not self.cmax and s>=self.vmax:
+            raise RuntimeError('Value must be < %f; found "%f"'%(self.vmax, s))
+        return s
+    
         
 
-        else:
-            verbose.erro = erro
-    return verbose.erro
 
 # a map from key -> value, converter
 defaultParams = {
@@ -471,7 +517,6 @@ defaultParams = {
     # the verbosity setting
     'verbose.level'           : ['silent', validate_verbose],
     'verbose.fileo'           : ['sys.stdout', validate_verbose_fileo],
-    'verbose.erro'            : ['sys.stderr', validate_verbose_erro],            
 
     # line props    
     'lines.linewidth'   : [0.5, validate_float],     # line width in points
@@ -483,6 +528,10 @@ defaultParams = {
     'lines.markeredgewidth'       : [0.5, validate_float],     
     'lines.markersize'  : [6, validate_float],       # markersize, in points
     'lines.antialiased' : [True, validate_bool],     # antialised (no jaggies)
+    'lines.dash_joinstyle' : ['miter', validate_joinstyle],
+    'lines.solid_joinstyle' : ['miter', validate_joinstyle],    
+    'lines.dash_capstyle' : ['butt', validate_capstyle],
+    'lines.solid_capstyle' : ['projecting', validate_capstyle],       
     'lines.data_clipping' : [False, validate_bool],  # clip data
 
     # patch props    
@@ -504,9 +553,12 @@ defaultParams = {
     'font.cursive'      : ['cursive', validate_comma_sep_str],
     'font.fantasy'      : ['fantasy', validate_comma_sep_str],
     'font.monospace'    : ['monospace', validate_comma_sep_str],
+    'font.latex.package': ['type1cm', str],          # LaTeX font package: txfonts, pslatex, ...
 
     # text props
     'text.color'        : ['k', validate_color],     # black
+    'text.usetex'       : [False, validate_bool],
+    'text.tex.engine'   : ['tex', validate_tex_engine], # TeX or LaTeX
     'text.fontstyle'    : ['normal', str],
     'text.fontangle'    : ['normal', str],
     'text.fontvariant'  : ['normal', str],
@@ -521,7 +573,7 @@ defaultParams = {
     'image.origin'    : ['upper', str],  # lookup table    
 
     # axes props
-    'axes.hold'         : [True, validate_bool],    # background color; white    
+    'axes.hold'         : [True, validate_bool],    
     'axes.facecolor'    : ['w', validate_color],    # background color; white
     'axes.edgecolor'    : ['k', validate_color],    # edge color; black
     'axes.linewidth'    : [1.0, validate_float],    # edge linewidth
@@ -530,7 +582,7 @@ defaultParams = {
     'axes.labelsize'    : ['medium', validate_fontsize], # fontsize of the x any y labels
     'axes.labelcolor'   : ['k', validate_color],    # color of axis label
 
-    'polaraxes.grid'         : [True, validate_bool],   # display grid or not    
+    'polaraxes.grid'         : [True, validate_bool],   # display polar grid or not    
 
     # tick properties
     'tick.major.size'   : [5, validate_float],      # major tick size in points
@@ -552,12 +604,25 @@ defaultParams = {
     'figure.facecolor'  : [ 0.75, validate_color], # facecolor; scalar gray
     'figure.edgecolor'  : [ 'w', validate_color],  # edgecolor; white
 
+    'figure.subplot.left'   : [0.125, ValidateInterval(0, 1, closedmin=False, closedmax=False)],
+    'figure.subplot.right'  : [0.9, ValidateInterval(0, 1, closedmin=False, closedmax=False)],
+    'figure.subplot.bottom' : [0.1, ValidateInterval(0, 1, closedmin=False, closedmax=False)],
+    'figure.subplot.top'    : [0.9, ValidateInterval(0, 1, closedmin=False, closedmax=False)],
+    'figure.subplot.wspace' : [0.2, ValidateInterval(0, 1, closedmin=False, closedmax=True)],
+    'figure.subplot.hspace' : [0.2, ValidateInterval(0, 1, closedmin=False, closedmax=True)],                    
+    
+
     'savefig.dpi'       : [ 150, validate_float],   # DPI
     'savefig.facecolor' : [ 'w', validate_color],  # facecolor; white
     'savefig.edgecolor' : [ 'w', validate_color],  # edgecolor; white
     'savefig.orientation' : [ 'portait', validate_orientation],  # edgecolor; white
 
     'tk.window_focus'   : [ False, validate_bool],  # Maintain shell focus for TkAgg
+    'tk.pythoninspect'   : [ False, validate_bool],  # Set PYTHONINSPECT
+    'ps.papersize'      : [ 'letter', validate_ps_papersize], # Set the papersize/type
+    'ps.useafm'   : [ False, validate_bool],  # Set PYTHONINSPECT
+    'ps.usedistiller'   : [ False, validate_bool],  # use ghostscript to distill ps output
+    'ps.distiller.res'  : [6000, validate_int],       # dpi
     'plugins.directory' : ['.matplotlib_plugins', str], # where plugin directory is locate
 
     }
@@ -595,7 +660,7 @@ def matplotlib_fname():
     path =  get_data_path() # guaranteed to exist or raise
     fname = os.path.join(path, '.matplotlibrc')
     if not os.path.exists(fname):
-        verbose.report_error('Could not find .matplotlibrc; using defaults')
+        warnings.warn('Could not find .matplotlibrc; using defaults')
     return fname
 
 
@@ -616,7 +681,7 @@ def rc_params():
     if not os.path.exists(fname):
         message = 'could not find rc file; returning defaults'
         ret =  dict([ (key, tup[0]) for key, tup in defaultParams.items()])
-        verbose.report_error(message)
+        warnings.warn(message)
         return ret
         
     cnt = 0
@@ -627,18 +692,18 @@ def rc_params():
         if line.startswith('#'): continue
         tup = line.split(':',1)
         if len(tup) !=2:
-            verbose.report_error('Illegal line #%d\n\t%s\n\tin file "%s"' % (cnt, line, fname))
+            warnings.warn('Illegal line #%d\n\t%s\n\tin file "%s"' % (cnt, line, fname))
             continue
 
         key, val = tup
         key = key.strip()
         if key in deprecated_map.keys():
             alt = deprecated_map[key]
-            verbose.report_error('%s is deprecated in .matplotlibrc - use %s instead.' % (key, alt))
+            warnings.warn('%s is deprecated in .matplotlibrc - use %s instead.' % (key, alt))
             key = alt
             
         if not defaultParams.has_key(key):
-            verbose.report_error('Bad key "%s" on line %d in %s' % (key, cnt, fname))
+            warnings.warn('Bad key "%s" on line %d in %s' % (key, cnt, fname))
             continue
 
         
@@ -650,7 +715,7 @@ def rc_params():
         val = val.strip()
         try: cval = converter(val)   # try to convert to proper type or raise
         except Exception, msg:
-            verbose.report_error('Bad val "%s" on line #%d\n\t"%s"\n\tin file "%s"\n\t%s' % (val, cnt, line, fname, msg))
+            warnings.warn('Bad val "%s" on line #%d\n\t"%s"\n\tin file "%s"\n\t%s' % (val, cnt, line, fname, msg))
             continue
         else:
             # Alles Klar, update dict
@@ -693,15 +758,10 @@ def rc(group, **kwargs):
         'mec' : 'markeredgecolor'
         'mew' : 'markeredgewidth'
         'aa'  : 'antialiased'            
-        'l'   : 'lines'
-        'a'   : 'axes'
-        'f'   : 'figure'
-        'p'   : 'patches'
-        'g'   : 'grid'
 
     Thus you could abbreviate the above rc command as
 
-          rc('l', lw=2, c='r')
+          rc('lines', lw=2, c='r')
 
 
     Note you can use python's kwargs dictionary facility to store
@@ -729,11 +789,6 @@ def rc(group, **kwargs):
         'mec' : 'markeredgecolor',
         'mew' : 'markeredgewidth',
         'aa'  : 'antialiased',                        
-        'l'   : 'lines',
-        'a'   : 'axes',
-        'f'   : 'figure',
-        'p'   : 'patches',
-        'g'   : 'grid',        
         }
     
     for k,v in kwargs.items():
@@ -761,9 +816,9 @@ def rcdefaults():
 # flag)
 
 _knownBackends = {
-    'Agg':1, 'Cairo':1, 'FltkAgg':1, 'GD':1, 'GDK':1, 'GTK':1, 'GTKAgg':1,
-    'GTKCairo':1, 'Paint':1, 'PS':1, 'SVG':1, 'Template':1, 'TkAgg':1, 'WX':1,
-    'WXAgg':1, }
+    'Agg2':1, 'Agg':1, 'Cairo':1, 'FltkAgg':1, 'GD':1, 'GDK':1, 'GTK':1, 'GTKAgg':1,
+    'GTKCairo':1, 'Paint':1, 'PS':1, 'LaTeX':1, 'QtAgg':1, 'SVG':1, 'Template':1,
+    'TkAgg':1, 'WX':1, 'WXAgg':1, }
 
 
 known = _knownBackends.keys()
@@ -783,9 +838,10 @@ def use(arg):
     """
     
     if not _knownBackends.has_key(arg):
-        verbose.report_error('unrecognized backend %s.\n' % arg +\
+        raise ValueError('unrecognized backend %s.\n' % arg +\
               'Use one of %s' % ', '.join( _knownBackends.keys() ))
-        sys.exit()
+
+
     rcParams['backend'] = arg
 
 def get_backend():
@@ -809,7 +865,7 @@ def tk_window_focus():
      This currently works only for python.exe and IPython.exe.
      Both IDLE and Pythonwin.exe fail badly when tk_window_focus is on."""
     if rcParams['backend'] != 'TkAgg':
-	return False    
+        return False    
     return rcParams['tk.window_focus']
 
 
