@@ -49,6 +49,7 @@ latex_to_bakoma = {
     r'\Rightparen'          : ('cmex10',  81),
     r'\LEFTparen'           : ('cmex10', 119),
     r'\RIGHTparen'          : ('cmex10',  87),
+    r'\LEFTbracket'         : ('cmex10', 125),
     r'\RIGHTbracket'        : ('cmex10',  93),
     r'\LEFTbrace'           : ('cmex10',  70),
     r'\RIGHTbrace'          : ('cmex10', 107),
@@ -236,6 +237,7 @@ latex_to_bakoma = {
     r'\equiv'               : ('cmsy10',  35),
     r'\subseteq'            : ('cmsy10', 103),
     r'\supseteq'            : ('cmsy10',  42),
+    r'\leq'                 : ('cmsy10',  14),
     r'\geq'                 : ('cmsy10',  29),
     r'\preceq'              : ('cmsy10',  79),
     r'\succeq'              : ('cmsy10', 131),
@@ -251,7 +253,192 @@ latex_to_bakoma = {
     r'\spadesuit'           : ('cmsy10',   7),
     }
 
-
+# the kerning dictionary in design space units
+cmkern = {
+    'cmr10' :
+    {
+        ('A', 't') : -0.027779,
+        ('A', 'C') : -0.027779,
+        ('A', 'O') : -0.027779,
+        ('A', 'G') : -0.027779,
+        ('A', 'U') : -0.027779,
+        ('A', 'Q') : -0.027779,
+        ('A', 'T') : -0.083334,
+        ('A', 'Y') : -0.083334,
+        ('A', 'V') : -0.111112,
+        ('A', 'W') : -0.111112,
+        ('D', 'X') : -0.027779,
+        ('D', 'W') : -0.027779,
+        ('D', 'A') : -0.027779,
+        ('D', 'V') : -0.027779,
+        ('D', 'Y') : -0.027779,
+        ('F', 'o') : -0.083334,
+        ('F', 'e') : -0.083334,
+        ('F', 'u') : -0.083334,
+        ('F', 'r') : -0.083334,
+        ('F', 'a') : -0.083334,
+        ('F', 'A') : -0.111112,
+        ('F', 'O') : -0.027779,
+        ('F', 'C') : -0.027779,
+        ('F', 'G') : -0.027779,
+        ('F', 'Q') : -0.027779,
+        ('I', 'I') : 0.027779,
+        ('K', 'O') : -0.027779,
+        ('K', 'C') : -0.027779,
+        ('K', 'G') : -0.027779,
+        ('K', 'Q') : -0.027779,
+        ('L', 'T') : -0.083334,
+        ('L', 'Y') : -0.083334,
+        ('L', 'V') : -0.111112,
+        ('L', 'W') : -0.111112,
+        ('O', 'X') : -0.027779,
+        ('O', 'W') : -0.027779,
+        ('O', 'A') : -0.027779,
+        ('O', 'V') : -0.027779,
+        ('O', 'Y') : -0.027779,
+        ('P', 'A') : -0.083334,
+        ('P', 'o') : -0.027779,
+        ('P', 'e') : -0.027779,
+        ('P', 'a') : -0.027779,
+        ('R', 't') : -0.027779,
+        ('R', 'C') : -0.027779,
+        ('R', 'O') : -0.027779,
+        ('R', 'G') : -0.027779,
+        ('R', 'U') : -0.027779,
+        ('R', 'Q') : -0.027779,
+        ('R', 'T') : -0.083334,
+        ('R', 'Y') : -0.083334,
+        ('R', 'V') : -0.111112,
+        ('R', 'W') : -0.111112,
+        ('T', 'y') : -0.027779,
+        ('T', 'e') : -0.083334,
+        ('T', 'o') : -0.083334,
+        ('T', 'r') : -0.083334,
+        ('T', 'a') : -0.083334,
+        ('T', 'A') : -0.083334,
+        ('T', 'u') : -0.083334,
+        ('V', 'o') : -0.083334,
+        ('V', 'e') : -0.083334,
+        ('V', 'u') : -0.083334,
+        ('V', 'r') : -0.083334,
+        ('V', 'a') : -0.083334,
+        ('V', 'A') : -0.111112,
+        ('V', 'O') : -0.027779,
+        ('V', 'C') : -0.027779,
+        ('V', 'G') : -0.027779,
+        ('V', 'Q') : -0.027779,
+        ('W', 'o') : -0.083334,
+        ('W', 'e') : -0.083334,
+        ('W', 'u') : -0.083334,
+        ('W', 'r') : -0.083334,
+        ('W', 'a') : -0.083334,
+        ('W', 'A') : -0.111112,
+        ('W', 'O') : -0.027779,
+        ('W', 'C') : -0.027779,
+        ('W', 'G') : -0.027779,
+        ('W', 'Q') : -0.027779,
+        ('X', 'O') : -0.027779,
+        ('X', 'C') : -0.027779,
+        ('X', 'G') : -0.027779,
+        ('X', 'Q') : -0.027779,
+        ('Y', 'e') : -0.083334,
+        ('Y', 'o') : -0.083334,
+        ('Y', 'r') : -0.083334,
+        ('Y', 'a') : -0.083334,
+        ('Y', 'A') : -0.083334,
+        ('Y', 'u') : -0.083334,
+        ('a', 'v') : -0.027779,
+        ('a', 'j') : 0.055555,
+        ('a', 'y') : -0.027779,
+        ('a', 'w') : -0.027779,
+        ('b', 'e') : 0.027779,
+        ('b', 'o') : 0.027779,
+        ('b', 'x') : -0.027779,
+        ('b', 'd') : 0.027779,
+        ('b', 'c') : 0.027779,
+        ('b', 'q') : 0.027779,
+        ('b', 'v') : -0.027779,
+        ('b', 'j') : 0.055555,
+        ('b', 'y') : -0.027779,
+        ('b', 'w') : -0.027779,
+        ('c', 'h') : -0.027779,
+        ('c', 'k') : -0.027779,
+        ('g', 'j') : 0.027779,
+        ('h', 't') : -0.027779,
+        ('h', 'u') : -0.027779,
+        ('h', 'b') : -0.027779,
+        ('h', 'y') : -0.027779,
+        ('h', 'v') : -0.027779,
+        ('h', 'w') : -0.027779,
+        ('k', 'a') : -0.055555,
+        ('k', 'e') : -0.027779,
+        ('k', 'a') : -0.027779,
+        ('k', 'o') : -0.027779,
+        ('k', 'c') : -0.027779,
+        ('m', 't') : -0.027779,
+        ('m', 'u') : -0.027779,
+        ('m', 'b') : -0.027779,
+        ('m', 'y') : -0.027779,
+        ('m', 'v') : -0.027779,
+        ('m', 'w') : -0.027779,
+        ('n', 't') : -0.027779,
+        ('n', 'u') : -0.027779,
+        ('n', 'b') : -0.027779,
+        ('n', 'y') : -0.027779,
+        ('n', 'v') : -0.027779,
+        ('n', 'w') : -0.027779,
+        ('o', 'e') : 0.027779,
+        ('o', 'o') : 0.027779,
+        ('o', 'x') : -0.027779,
+        ('o', 'd') : 0.027779,
+        ('o', 'c') : 0.027779,
+        ('o', 'q') : 0.027779,
+        ('o', 'v') : -0.027779,
+        ('o', 'j') : 0.055555,
+        ('o', 'y') : -0.027779,
+        ('o', 'w') : -0.027779,
+        ('p', 'e') : 0.027779,
+        ('p', 'o') : 0.027779,
+        ('p', 'x') : -0.027779,
+        ('p', 'd') : 0.027779,
+        ('p', 'c') : 0.027779,
+        ('p', 'q') : 0.027779,
+        ('p', 'v') : -0.027779,
+        ('p', 'j') : 0.055555,
+        ('p', 'y') : -0.027779,
+        ('p', 'w') : -0.027779,
+        ('t', 'y') : -0.027779,
+        ('t', 'w') : -0.027779,
+        ('u', 'w') : -0.027779,
+        ('v', 'a') : -0.055555,
+        ('v', 'e') : -0.027779,
+        ('v', 'a') : -0.027779,
+        ('v', 'o') : -0.027779,
+        ('v', 'c') : -0.027779,
+        ('w', 'e') : -0.027779,
+        ('w', 'a') : -0.027779,
+        ('w', 'o') : -0.027779,
+        ('w', 'c') : -0.027779,
+        ('y', 'o') : -0.027779,
+        ('y', 'e') : -0.027779,
+        ('y', 'a') : -0.027779,
+        },
+    'cmex10' : {},
+    'cmtt10' : {},
+    'cmsy10' : {},
+    'cmmi10' :
+    {
+    ('9', 'A') : -0.055555,
+    ('9', 'M') : -0.055555,
+    ('9', 'N') : -0.055555,
+    ('9', 'Y') : 0.055555,
+    ('9', 'Z') : -0.055555,
+    ('d', 'Y') : 0.055555,
+    ('d', 'Z') : -0.055555,
+    ('d', 'j') : -0.111112,
+    ('d', 'f') : -0.166667,
+    },
+    }
 ams_type1 = {
     r'\Leftbracket'       : ( 'cmex10', '02'),
     r'\Rightbracket'      : ( 'cmex10', '03'),
